@@ -40,8 +40,8 @@ class Audio {
 	void setSoundVolume(int soundVolume);
 	void setMusicVolume(int musicVolume);
 	void registerEngine(Engine *engine);
-	bool loadSound(int i, char *filename);
-	bool loadMusic(char *filename);
+	bool loadSound(int i, const char *filename);
+	bool loadMusic(const char *filename);
 	void playSound(int snd, int channel);
 	void playSound(int snd, int channel, int loops);
 	void playMusic();
