@@ -32,7 +32,7 @@ Data::~Data()
 	destroy();
 }
 
-void Data::set(char *key, char *value, bool complete)
+void Data::set(const char *key, const char *value, bool complete)
 {
 	if ((strlen(key) > 50) || (strlen(value) > 50))
 	{
