@@ -28,7 +28,7 @@ class Data : public GameObject{
 		
 	Data();
 	virtual ~Data();
-	void set(char *key, char *value, bool complete);
+	void set(const char *key, const char *value, bool complete);
 	void destroy();
 
 };
