@@ -24,7 +24,7 @@ Engine::Engine()
 {
 	for (int i = 0 ; i < 350 ; i++)
 		keyState[i] = 0;
-		
+
 	strcpy(lastInput, "");
 
 	// Mouse stuff
@@ -33,11 +33,7 @@ Engine::Engine()
 
 	strcpy(lastKeyPressed, "");
 
-	#if USEPAK
-		fullScreen = 1;
-	#else
-		fullScreen = 0;
-	#endif
+	fullScreen = 0;
 
 	useAudio = 2;
 
@@ -52,11 +48,11 @@ Engine::Engine()
 	// Timer
 	time1 = time2 = 0;
 	timeDifference = 0;
-	
+
 	pak.setPakFile(PAKFULLPATH);
-	
+
 	defineList.clear();
-	
+
 	allowQuit = false;
 }
 
@@ -252,7 +248,7 @@ void Engine::clearInput()
 	mouseWheelUp = mouseWheelDown = 0;
 }
 
-void Engine::setUserHome(char *path)
+void Engine::setUserHome(const char *path)
 {
 	strcpy(userHomeDirectory, path);
 	debug(("User Home = %s\n", path));
@@ -264,7 +260,7 @@ it is found, the data is read into a character buffer.
 In the case of music, the data music be written to a temporary directory
 since SDL currently provides no means to load music directly from memory
 */
-bool Engine::unpack(char *filename, int fileType)
+bool Engine::unpack(const char *filename, int fileType)
 {
 	if (fileType == PAK_DATA)
 	{
@@ -309,7 +305,7 @@ bool Engine::unpack(char *filename, int fileType)
 	if ((fileType == PAK_MUSIC) || (fileType == PAK_FONT))
 	{
 		char tempPath[PATH_MAX];
-		
+
 		FILE *fp = NULL;
 
 		if (fileType == PAK_MUSIC)
@@ -338,14 +334,14 @@ bool Engine::unpack(char *filename, int fileType)
 	return true;
 }
 
-bool Engine::loadData(char *filename)
+bool Engine::loadData(const char *filename)
 {
 	if (dataBuffer != NULL)
 	{
 		delete[] dataBuffer;
 		dataBuffer = NULL;
 	}
-	
+
 	#if USEPAK
 		return unpack(filename, PAK_DATA);
 	#endif
@@ -388,12 +384,12 @@ void Engine::freeLocaleInfo()
 	localeList.clear();
 }
 
-bool Engine::getLocaleInformation(char *section)
+bool Engine::getLocaleInformation(const char *section)
 {
 	return true;
 }
 
-char *Engine::translate(char *key)
+const char *Engine::translate(const char *key)
 {
 	if (strcmp(language, "en") == 0)
 		return key;
@@ -445,7 +441,7 @@ void Engine::addWidget(Widget *widget)
 	widgetList.add(widget);
 }
 
-bool Engine::loadWidgets(char *filename)
+bool Engine::loadWidgets(const char *filename)
 {
 	deleteWidgets();
 
@@ -506,7 +502,7 @@ bool Engine::loadWidgets(char *filename)
 	return true;
 }
 
-Widget *Engine::getWidgetByName(char *name)
+Widget *Engine::getWidgetByName(const char *name)
 {
 	Widget *widget = (Widget*)widgetList.getHead();
 
@@ -523,7 +519,7 @@ Widget *Engine::getWidgetByName(char *name)
 	return NULL;
 }
 
-void Engine::showWidgetGroup(char *groupName, bool show)
+void Engine::showWidgetGroup(const char *groupName, bool show)
 {
 	bool found = false;
 
@@ -545,7 +541,7 @@ void Engine::showWidgetGroup(char *groupName, bool show)
 		debug(("Group '%s' does not exist\n", groupName));
 }
 
-void Engine::enableWidgetGroup(char *groupName, bool show)
+void Engine::enableWidgetGroup(const char *groupName, bool show)
 {
 	bool found = false;
 
@@ -567,7 +563,7 @@ void Engine::enableWidgetGroup(char *groupName, bool show)
 		debug(("Group '%s' does not exist\n", groupName));
 }
 
-void Engine::showWidget(char *name, bool show)
+void Engine::showWidget(const char *name, bool show)
 {
 	Widget *widget = getWidgetByName(name);
 	if (widget != NULL)
@@ -577,7 +573,7 @@ void Engine::showWidget(char *name, bool show)
 	}
 }
 
-void Engine::enableWidget(char *name, bool enable)
+void Engine::enableWidget(const char *name, bool enable)
 {
 	Widget *widget = getWidgetByName(name);
 	if (widget != NULL)
@@ -587,21 +583,21 @@ void Engine::enableWidget(char *name, bool enable)
 	}
 }
 
-void Engine::setWidgetVariable(char *name, int *variable)
+void Engine::setWidgetVariable(const char *name, int *variable)
 {
 	Widget *widget = getWidgetByName(name);
 	if (widget != NULL)
 		widget->setValue(variable);
 }
 
-void Engine::setWidgetVariable(char *name, char *variable)
+void Engine::setWidgetVariable(const char *name, const char *variable)
 {
 	//Widget *widget = getWidgetByName(name);
 	//if (widget != NULL)
 		//widget->setValue(variable);
 }
 
-bool Engine::widgetChanged(char *name)
+bool Engine::widgetChanged(const char *name)
 {
 	Widget *widget = getWidgetByName(name);
 	if (widget != NULL)
@@ -681,7 +677,7 @@ void Engine::highlightWidget(int dir)
 	highlightedWidget->redraw();
 }
 
-void Engine::highlightWidget(char *name)
+void Engine::highlightWidget(const char *name)
 {
 	highlightedWidget = getWidgetByName(name);
 }
@@ -689,7 +685,7 @@ void Engine::highlightWidget(char *name)
 int Engine::processWidgets()
 {
 	int update = 0;
-	
+
 	if (highlightedWidget->changed)
 		return 3;
 
@@ -761,13 +757,13 @@ int Engine::processWidgets()
 				highlightedWidget->changed = true;
 			}
 		}
-		
+
 		update = 2;
 
 		flushInput();
 		clearInput();
 	}
-	
+
 	if (keyState[SDLK_TAB])
 	{
 		if (highlightedWidget->type == WG_INPUT)
@@ -811,7 +807,7 @@ bool Engine::loadDefines()
 			defineList.add(data);
 		}
 	}
-	
+
 	return true;
 }
 
@@ -822,7 +818,7 @@ traverse the list and return 1 when it encounters ACTIVE. This has two advantage
 the code, I don't have to change all the data entries too. You probably already
 thought of that though... :)
 */
-int Engine::getValueOfDefine(char *word)
+int Engine::getValueOfDefine(const char *word)
 {
 	int rtn = 0;
 
@@ -844,7 +840,7 @@ int Engine::getValueOfDefine(char *word)
 	exit(1);
 }
 
-char *Engine::getProperty(char *word)
+char *Engine::getProperty(const char *word)
 {
 	Data *data = (Data*)defineList.getHead();
 
@@ -856,13 +852,13 @@ char *Engine::getProperty(char *word)
 			return data->value;
 	}
 
-	debug(("getProperty() : %s is not defined!\n", word));
-	
+	//debug(("getProperty() : %s is not defined!\n", word));
+
 	return NULL;
 }
 
 #if !UNIX
-char *strtok_r(char *in, char *delim, char **nextPos)
+char *strtok_r(char *in, const char *delim, char **nextPos)
 {
 	char* rtnBuf;
 	char* testChar;
@@ -924,7 +920,7 @@ the function above, delimited with plus signs. So ENT_FLIES+ENT_AIMS. It then wo
 flags (in a bit of a half arsed manner because of my lazy (2 << 25) declarations, adds all
 the values together and then returns them... phew! Makes data files human readable though :)
 */
-int Engine::getValueOfFlagTokens(char *realLine)
+int Engine::getValueOfFlagTokens(const char *realLine)
 {
 	if (strcmp(realLine, "0") == 0)
 		return 0;
@@ -972,7 +968,7 @@ int Engine::getValueOfFlagTokens(char *realLine)
 				break;
 			}
 		}
-		
+
 		if (!found)
 		{
 			printf("getValueOfFlagTokens() : Illegal Token %s\n", word);
