@@ -66,6 +66,20 @@ void Graphics::destroy()
 	for (int i = 0 ; i < 100 ; i++)
 		if (tile[i] != NULL)
 			SDL_FreeSurface(tile[i]);
+		
+	if (medalMessage != NULL)
+	{
+		SDL_FreeSurface(medalMessage);
+	}
+	
+	for (int i = 0 ; i < 4 ; i++)
+	{
+		if (medal[i] != NULL)
+		{
+			SDL_FreeSurface(medal[i]);
+			medal[i] = NULL;
+		}
+	}
 }
 
 void Graphics::mapColors()
@@ -108,8 +122,26 @@ void Graphics::setTransparent(SDL_Surface *sprite)
 	SDL_SetColorKey(sprite, (SDL_SRCCOLORKEY|SDL_RLEACCEL), SDL_MapRGB(sprite->format, 0, 0, 0));
 }
 
+bool Graphics::canShowMedalMessage()
+{
+	return (medalMessageTimer <= 0);
+}
+
 void Graphics::updateScreen()
 {
+	if (medalMessageTimer > 0)
+	{
+		medalMessageTimer -= engine->getTimeDifference();
+		drawRect(screen->w - (medalMessage->w + 5 + 18), 5, medalMessage->w + 16, 20, grey, screen);
+		drawRect(screen->w - (medalMessage->w + 5 + 17), 6, medalMessage->w + 14, 18, black, screen);
+		blit(medalMessage, screen->w - (medalMessage->w + 5), 7, screen, false);
+		
+		if (medalType >= 0)
+		{
+			blit(medal[medalType], screen->w - (medalMessage->w + 5 + 16), 7, screen, false);
+		}
+	}
+	
 	SDL_Flip(screen);
 	animateSprites();
 	SDL_Delay((int)engine->getTimeDifference());
@@ -248,7 +280,7 @@ void Graphics::HSVtoRGB(float *r, float *g, float *b, float h, float s, float v)
 	}
 }
 
-SDL_Surface *Graphics::loadImage(char *filename)
+SDL_Surface *Graphics::loadImage(const char *filename)
 {
 	SDL_Surface *image, *newImage;
 
@@ -280,7 +312,7 @@ SDL_Surface *Graphics::loadImage(char *filename)
 	return newImage;
 }
 
-SDL_Surface *Graphics::loadImage(char *filename, int hue, int sat, int value)
+SDL_Surface *Graphics::loadImage(const char *filename, int hue, int sat, int value)
 {
 	SDL_Surface *image, *newImage;
 
@@ -350,7 +382,7 @@ SDL_Surface *Graphics::loadImage(char *filename, int hue, int sat, int value)
 	return newImage;
 }
 
-SDL_Surface *Graphics::quickSprite(char *name, SDL_Surface *image)
+SDL_Surface *Graphics::quickSprite(const char *name, SDL_Surface *image)
 {
 	Sprite *sprite = addSprite(name);
 	sprite->setFrame(0, image, 60);
@@ -383,7 +415,7 @@ If a user has a resolution other than approximately 72dpi then
 they will get a small or larger font and this won't work. This might look
 weird since we'll load and delete multiple fonts, but it works...
 */
-void Graphics::loadFont(int i, char *filename, int pixelSize)
+void Graphics::loadFont(int i, const char *filename, int pixelSize)
 {
 	int minx, maxx, miny, maxy, advance;
 	
@@ -456,7 +488,7 @@ void Graphics::loadFont(int i, char *filename, int pixelSize)
 	debug(("Got a match for font size %d - Nearest = %d\n", pixelSize, maxx));
 }
 
-Sprite *Graphics::addSprite(char *name)
+Sprite *Graphics::addSprite(const char *name)
 {
 	Sprite *sprite = new Sprite;
 	strcpy(sprite->name, name);
@@ -467,7 +499,7 @@ Sprite *Graphics::addSprite(char *name)
 	return sprite;
 }
 
-Sprite *Graphics::getSprite(char *name, bool required)
+Sprite *Graphics::getSprite(const char *name, bool required)
 {
 	Sprite *sprite = spriteHead;
 
@@ -497,7 +529,7 @@ void Graphics::animateSprites()
 	}
 }
 
-void Graphics::loadBackground(char *filename)
+void Graphics::loadBackground(const char *filename)
 {
 	if (background != NULL)
 	{
@@ -633,6 +665,50 @@ void Graphics::blit(SDL_Surface *image, int x, int y, SDL_Surface *dest, bool ce
 		showErrorAndExit("graphics::blit() - %s", SDL_GetError());
 }
 
+void Graphics::showMedalMessage(int type, const char *in)
+{
+	if (medalMessage != NULL)
+	{
+		SDL_FreeSurface(medalMessage);
+	}
+	
+	setFontSize(0);
+	
+	switch (type)
+	{
+		// Bronze
+		case 1:
+			setFontColor(0xA6, 0x7D, 0x3D, 0x00, 0x00, 0x00);
+			break;
+		
+		// Silver
+		case 2:
+			setFontColor(0xC0, 0xC0, 0xC0, 0x00, 0x00, 0x00);
+			break;
+			
+		// Gold
+		case 3:
+			setFontColor(0xFF, 0xCC, 0x33, 0x00, 0x00, 0x00);
+			break;
+			
+		// Ruby
+		case 4:
+			setFontColor(0xFF, 0x11, 0x55, 0x00, 0x00, 0x00);
+			break;
+	}
+	
+	medalType = type - 1; // for indexing on the image
+	if (type != -1)
+	{
+		medalMessage = getString(true, "  Medal Earned - %s  ", in);
+	}
+	else
+	{
+		medalMessage = getString(true, "  %s  ", in);
+	}
+	medalMessageTimer = (5 * 60);
+}
+
 void Graphics::drawBackground()
 {
 	if (background != NULL)
@@ -687,7 +763,7 @@ void Graphics::setFontSize(int size)
 	Math::limitInt(&fontSize, 0, 4);
 }
 
-SDL_Surface *Graphics::getString(bool transparent, char *in, ...)
+SDL_Surface *Graphics::getString(bool transparent, const char *in, ...)
 {
 	va_list argp;
 	va_start(argp, in);
@@ -708,7 +784,7 @@ SDL_Surface *Graphics::getString(bool transparent, char *in, ...)
 	return text;
 }
 
-void Graphics::drawString(int x, int y, int alignment, SDL_Surface *dest, char *in, ...)
+void Graphics::drawString(int x, int y, int alignment, SDL_Surface *dest, const char *in, ...)
 {
 	va_list argp;
 	va_start(argp, in);
@@ -784,7 +860,7 @@ SDL_Surface *Graphics::alphaRect(int width, int height, Uint8 red, Uint8 green,
 
 	SDL_FillRect(surface, NULL, SDL_MapRGB(surface->format, red, green, blue));
 
-	SDL_SetAlpha(surface, SDL_SRCALPHA|SDL_RLEACCEL, 128);
+	SDL_SetAlpha(surface, SDL_SRCALPHA|SDL_RLEACCEL, 130);
 
 	return surface;
 }
@@ -818,7 +894,7 @@ void Graphics::unlock(SDL_Surface *surface)
 	}
 }
 
-void Graphics::showErrorAndExit(char *error, char *param)
+void Graphics::showErrorAndExit(const char *error, const char *param)
 {
 	clearScreen(black);
 
