@@ -28,7 +28,7 @@ HighScore::HighScore()
 	level = 0;
 }
 
-void HighScore::set(char *name, int score, int kills, int level)
+void HighScore::set(const char *name, int score, int kills, int level)
 {
 	strcpy(this->name, name);
 	this->score = score;
