@@ -28,6 +28,6 @@ class HighScore {
 		unsigned int level;
 
 	HighScore();
-	void set(char *name, int score, int kills, int level);
+	void set(const char *name, int score, int kills, int level);
 
 };
