@@ -41,7 +41,7 @@ class Widget : public GameObject {
 
 	Widget();
 	virtual ~Widget();
-	void setProperties(char *name, char *groupName, char *label, char *options, int x, int y, int min, int max);
+	void setProperties(const char *name, const char *groupName, const char *label, const char *options, int x, int y, int min, int max);
 	void setValue(int *value);
 	void redraw();
 	void destroy();
