@@ -20,6 +20,86 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "game.h"
 
+int medalWorker(void *data)
+{
+	char *tname = (char*)data;
+	
+	SDL_mutexP(medalServer.lock);
+	
+	int type = medalServer.postMedal(tname);
+	
+	while (!graphics.canShowMedalMessage())
+	{
+		SDL_Delay(100);
+	}
+	
+	SDL_Delay(100);
+	
+	if (type >= 1 && type <= 3)
+	{
+		audio.playSound(SND_ITEM, 0);
+		graphics.showMedalMessage(type, medalServer.getMessage());
+		
+		if (medalServer.hasRuby())
+		{
+			while (!graphics.canShowMedalMessage())
+			{
+				SDL_Delay(100);
+			}
+			
+			SDL_Delay(100);
+			
+			audio.playSound(SND_ITEM, 0);
+			graphics.showMedalMessage(4, medalServer.getRubyMessage());
+		}
+	}
+	
+	SDL_mutexV(medalServer.lock);
+	
+	delete tname;
+	
+	return type;
+}
+
+void presentPlayerMedal(const char *tname)
+{
+	// Copy the input, so that threading
+	// doesn't trip us up!
+	char *data = new char[128];
+	strcpy(data, tname);
+	
+	SDL_Thread *thread = SDL_CreateThread(medalWorker, (void*)data);
+	
+	if (thread == NULL)
+	{
+		printf("Unable to create thread: %s\n", SDL_GetError());
+		printf("Calling medal server directly\n");
+		medalWorker((void*)data);
+		return;
+	}
+}
+
+void addScore(int amount)
+{
+	if (gameData.skill > MODE_EASY && gameData.skill < MODE_NIGHTMARE)
+	{
+		if (gameData.score < 1000000 && gameData.score + amount >= 1000000)
+		{
+			presentPlayerMedal("VK_Score1000000");
+		}
+		else if (gameData.score < 500000 && gameData.score + amount >= 500000)
+		{
+			presentPlayerMedal("VK_Score500000");
+		}
+		else if (gameData.score < 250000 && gameData.score + amount >= 250000)
+		{
+			presentPlayerMedal("VK_Score250000");
+		}
+	}
+	
+	gameData.score += amount;
+}
+
 int showInGameOptions()
 {
 	float brightness;
@@ -319,6 +399,23 @@ void doRoundClear()
 	bonus *= (gameData.activeDirs * 10);
 
 	unsigned int then = SDL_GetTicks() + 2000;
+	
+	if (gameData.level + 1 == 5)
+	{
+		presentPlayerMedal("VK_Round5");
+	}
+	else if (gameData.level + 1 == 10)
+	{
+		presentPlayerMedal("VK_Round10");
+	}
+	else if (gameData.level + 1 == 15)
+	{
+		presentPlayerMedal("VK_Round15");
+	}
+	else if (gameData.level + 1 == 20)
+	{
+		presentPlayerMedal("VK_Round20");
+	}
 
 	while (true)
 	{
@@ -392,7 +489,7 @@ void doRoundClear()
 
 	engine.resetTimeDifference();
 	
-	gameData.score += bonus;
+	addScore(bonus);
 }
 
 int doGame()
@@ -596,8 +693,7 @@ int doGame()
 
 			lastTime = (int)time;
 
-			if ((gameData.level % 5) == 0)
-				minViruses += 2;
+			minViruses += 2;
 
 			time = lastTime = now;
 			lastTime += (roundTime * 100);
@@ -732,6 +828,11 @@ int doGame()
 			engine.resetTimeDifference();
 		}
 	}
+	
+	if (gameData.score <= -100000)
+	{
+		presentPlayerMedal("VK_NegativeScore");
+	}
 
 	GameOver();
 
@@ -747,12 +848,15 @@ int doGame()
 			else
 			{
 				gameData.nightmareCount -= gameData.level;
+				Math::limitInt(&gameData.nightmareCount, 0, 100);
 			}
 
 			debug(("Nightmare Count is now %d\n", gameData.nightmareCount));
 
 			if (gameData.nightmareCount == 50)
 			{
+				presentPlayerMedal("VK_NightmareMode");
+				
 				graphics.clearScreen(graphics.black);
 				graphics.delay(500);
 				graphics.setFontSize(4);
@@ -763,6 +867,8 @@ int doGame()
 			}
 			else if (gameData.nightmareCount == 0)
 			{
+				presentPlayerMedal("VK_UltimateNightmareMode");
+				
 				graphics.clearScreen(graphics.black);
 				graphics.delay(500);
 				graphics.setFontSize(4);
