@@ -19,6 +19,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "headers.h"
+#include "SDL/SDL_thread.h"
 
 extern void addViruses(int amount);
 
@@ -43,3 +44,4 @@ extern Audio audio;
 extern Engine engine;
 extern GameData gameData;
 extern Graphics graphics;
+extern MedalServer medalServer;
