@@ -21,7 +21,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "headers.h"
 
 extern void loadResources();
-extern void buildFileList(char *dirName, int depth);
+extern void buildFileList(const char *dirName, int depth);
 extern void initSystem();
 extern void cleanup();
 
@@ -29,7 +29,10 @@ extern int doTitle();
 extern int doGame();
 extern int addHighScore();
 
+extern void presentPlayerMedal(const char *tname);
+
 Audio audio;
 Engine engine;
 GameData gameData;
 Graphics graphics;
+MedalServer medalServer;
