@@ -21,6 +21,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "headers.h"
 
 extern void addVirusDeathParticles(int x, int y, int virusType);
+extern void presentPlayerMedal(const char *tname);
+extern void addScore(int amount);
 
 extern Audio audio;
 extern Engine engine;
